<?php

namespace QUI\CmsImport\Entities;

use QUI;

abstract class AbstractImportEntity extends QUI\QDOM
{
    /**
     * @var string|int
     */
    protected string | int $identifier;

    /**
     * @var array
     */
    protected array $reviewFlags = [];

    /**
     * AbstractImportEntity constructor.
     * @param int|string $identifier - Unique identifier for this ImportEntity
     */
    public function __construct(int | string $identifier)
    {
        $this->identifier = $identifier;
    }

    /**
     * Flag this entity for review, so it is listed in a special "todo.log" after import
     *
     * @param string $reason (optional) - The reason why this site is flagged for review
     */
    public function addReviewFlag(string $reason = ''): void
    {
        $this->reviewFlags[] = $reason;
    }

    /**
     * @return array
     */
    public function getReviewFlags(): array
    {
        return $this->reviewFlags;
    }

    /**
     * @return bool
     */
    public function hasReviewFlags(): bool
    {
        return !empty($this->reviewFlags);
    }

    /**
     * @return int|string
     */
    public function getIdentifier(): int | string
    {
        return $this->identifier;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    abstract public function getImportSection(): string;
}
