<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportGroup
 *
 * Represents a QUIQQER user group that is imported
 */
class ImportGroup extends AbstractImportEntity implements CustomQuiqqerIdInterface
{
    /**
     * @var string
     */
    protected string $name;

    /**
     * @var bool
     */
    protected bool $hasAdminAccess = false;

    /**
     * @var ?int
     */
    protected ?int $quiqqerId = null;

    /**
     * QUIQQER permissions for this group
     *
     * @var array
     */
    protected array $quiqqerPermissions = [];

    /**
     * ImportGroup constructor.
     *
     * @param int|string $identifier - ImportGroup identifier
     * @param string $name - Project name
     * @param bool $hasAdminAccess (optional) - Group users have access to QUIQQER backend
     * @param array $attributes (optional) - Additional attributes
     */
    public function __construct(int | string $identifier, string $name, bool $hasAdminAccess, array $attributes = [])
    {
        $this->name = $name;
        $this->hasAdminAccess = $hasAdminAccess;

        $this->setAttributes($attributes);
        parent::__construct($identifier);
    }

    /**
     * @return int|string
     */
    public function getIdentifier(): int | string
    {
        return $this->identifier;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return bool
     */
    public function hasAdminAccess(): bool
    {
        return $this->hasAdminAccess;
    }

    /**
     * Set QUIQQER ID
     *
     * @param int $id
     * @return void
     */
    public function setQuiqqerId(int $id): void
    {
        $this->quiqqerId = $id;
    }

    /**
     * Return QUIQQER ID
     *
     * @return int|null
     */
    public function getQuiqqerId(): ?int
    {
        return $this->quiqqerId;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_GROUPS;
    }

    /**
     * Get QUIQQER permissions ($permissions => $permissionValue) for this group
     *
     * @return array
     */
    public function getQuiqqerPermissions(): array
    {
        return $this->quiqqerPermissions;
    }

    /**
     * Set QUIQQER permissions ($permissions => $permissionValue) for this group
     *
     * @param array $quiqqerPermissions
     */
    public function setQuiqqerPermissions(array $quiqqerPermissions): void
    {
        $this->quiqqerPermissions = $quiqqerPermissions;
    }
}
