<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportMediaItem
 *
 * Represents a QUIQQER media item that is imported
 */
class ImportMediaItem extends AbstractImportEntity implements CustomQuiqqerIdInterface
{
    const MEDIA_TYPE_IMAGE = 'image';
    const MEDIA_TYPE_FILE = 'file';
    const MEDIA_TYPE_FOLDER = 'folder';

    /**
     * @var int|string
     */
    protected string | int $projectIdentifier;

    /**
     * @var string
     */
    protected string $type;

    /**
     * @var string
     */
    protected string $title;

//    protected $short = null;
//    protected $active = false;
//    protected $createDate = null;
//    protected $altText = null;
//    protected $mimeType = null;
//    protected $imageHeight = null;
//    protected $imageWidth = null;
//    protected $roundCorners = null;


    /**
     * @var ?int
     */
    protected ?int $quiqqerId = null;

    /**
     * @var ?string - Absolute file path to associated file
     */
    protected ?string $file = null;

    /**
     * ImportProject constructor.
     *
     * @param string|int $identifier - Unique ImportMediaItem identifier
     * @param int|string $projectIdentifier - Unique ImportProject identifier
     * @param string $type - One of self::MEDIA_TYPE_*
     * @param string $title - Media item title
     * @param array $attributes (optional) - Additional Site attributes
     */
    public function __construct(
        int | string $identifier,
        int | string $projectIdentifier,
        string $type,
        string $title,
        array $attributes = []
    ) {
        $this->projectIdentifier = $projectIdentifier;
        $this->type = $type;
        $this->title = $title;

        $this->setAttributes($attributes);
        parent::__construct($identifier);
    }

    /**
     * @return string
     */
    public function getFile(): ?string
    {
        return $this->file;
    }

    /**
     * @param string $file
     */
    public function setFile(string $file): void
    {
        $this->file = $file;
    }

    /**
     * @return int|string
     */
    public function getIdentifier(): int | string
    {
        return $this->identifier;
    }

    /**
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * @return bool
     */
    public function isFolder(): bool
    {
        return $this->type === self::MEDIA_TYPE_FOLDER;
    }

    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * Set QUIQQER ID
     *
     * @param int $id
     * @return void
     */
    public function setQuiqqerId(int $id): void
    {
        $this->quiqqerId = $id;
    }

    /**
     * Return QUIQQER ID
     *
     * @return int|null
     */
    public function getQuiqqerId(): ?int
    {
        return $this->quiqqerId;
    }

    /**
     * @return string|int
     */
    public function getProjectIdentifier(): int | string
    {
        return $this->projectIdentifier;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_MEDIA;
    }
}
