<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportPermission
 *
 * Represents a QUIQQER permission
 */
class ImportPermission extends AbstractImportEntity
{
    /**
     * Possible Permission types ("What values can the permission hold?")
     */
    const TYPE_BOOL = 'bool';
    const TYPE_STRING = 'string';
    const TYPE_INT = 'int';
    const TYPE_ARRAY = 'array';
    const TYPE_GROUP = 'group';
    const TYPE_GROUPS = 'groups';
    const TYPE_USER = 'user';
    const TYPE_USERS = 'users';
    const TYPE_USERS_AND_GROUPS = 'users_and_groups';

    /**
     * Possible permission areas ("Who can hold the permission?")
     */
    const AREA_GLOBAL = 'global';
    const AREA_USER = 'user';
    const AREA_GROUPS = 'groups';
    const AREA_SITE = 'site';
    const AREA_PROJECT = 'project';
    const AREA_MEDIA = 'media';

    /**
     * @var string
     */
    protected string $permission;

    /**
     * @var string
     */
    protected string $area;

    /**
     * @var string
     */
    protected string $type;

    /**
     * Permission translations (title)
     *
     * @var array
     */
    protected array $translationsTitle = [];

    /**
     * Permission translations (description)
     *
     * @var array
     */
    protected array $translationsDescription = [];

    /**
     * ImportPermission constructor.
     *
     * @param int|string $identifier - Unique identifier
     * @param string $permission - Permission name
     * @param string $type (optional) - Permission type (must be one of self::TYPE_*)
     * @param string $area (optional) - Permission area (must be one of self::AREA_*)
     */
    public function __construct(
        int | string $identifier,
        string $permission,
        string $type = self::TYPE_BOOL,
        string $area = self::AREA_GLOBAL
    ) {
        $this->permission = $permission;
        $this->type = $type;
        $this->area = $area;
        parent::__construct($identifier);
    }

    /**
     * Set translation text for a permission title
     *
     * @param string $lang
     * @param string $translation
     * @return void
     */
    public function setTitleTranslation(string $lang, string $translation): void
    {
        $this->translationsTitle[$lang] = $translation;
    }

    /**
     * Set translation text for a permission description
     *
     * @param string $lang
     * @param string $translation
     * @return void
     */
    public function setDescriptionTranslation(string $lang, string $translation): void
    {
        $this->translationsDescription[$lang] = $translation;
    }

    /**
     * @return array
     */
    public function getTranslationsTitle(): array
    {
        return $this->translationsTitle;
    }

    /**
     * @return array
     */
    public function getTranslationsDescription(): array
    {
        return $this->translationsDescription;
    }

    /**
     * @return string
     */
    public function getPermission(): string
    {
        return $this->permission;
    }

    /**
     * @return string
     */
    public function getPermissionArea(): string
    {
        return $this->area;
    }

    /**
     * @return string
     */
    public function getPermissionType(): string
    {
        return $this->type;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_PERMISSIONS;
    }
}
