<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportTag
 *
 * Represents a QUIQQER tag group that is imported
 */
class ImportTag extends AbstractImportEntity
{
    /**
     * @var string
     */
    protected string $title;

    /**
     * @var string
     */
    protected string $description;

    /**
     * @var string
     */
    protected ?string $image = null;

    /**
     * @var string[] - ImportTagGroup identifiers
     */
    protected array $tagGroups = [];

    /**
     * ImportProject constructor.
     *
     * @param int|string $identifier - ImportTagGroup identifier
     * @param string $title - Tag title
     */
    public function __construct(int | string $identifier, string $title)
    {
        $this->title = $title;
        parent::__construct($identifier);
    }

    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * @return string
     */
    public function getDescription(): string
    {
        return $this->description;
    }

    /**
     * @param string $description
     */
    public function setDescription(string $description): void
    {
        $this->description = $description;
    }

    /**
     * @return string[]
     */
    public function getTagGroups(): array
    {
        return array_values(array_unique($this->tagGroups));
    }

    /**
     * @param string $tagGroup
     */
    public function addTagGroup(string $tagGroup): void
    {
        $this->tagGroups[] = $tagGroup;
    }

    /**
     * @return string
     */
    public function getImage(): ?string
    {
        return $this->image;
    }

    /**
     * @param string $image - QUIQQER Image URL
     */
    public function setImage(string $image): void
    {
        $this->image = $image;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_TAGS;
    }
}
