<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportTagGroup
 *
 * Represents a QUIQQER tag group that is imported
 */
class ImportTagGroup extends AbstractImportEntity
{
    /**
     * @var string
     */
    protected string $title;

    /**
     * @var string
     */
    protected string $description;

    /**
     * @var int
     */
    protected int $priority;

    /**
     * ImportProject constructor.
     *
     * @param int|string $identifier - ImportTagGroup identifier
     * @param string $title - Tag title
     */
    public function __construct(int | string $identifier, string $title)
    {
        $this->title = $title;
        parent::__construct($identifier);
    }

    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * @return string
     */
    public function getDescription(): string
    {
        return $this->description;
    }

    /**
     * @param string $description
     */
    public function setDescription(string $description): void
    {
        $this->description = $description;
    }

    /**
     * @return int
     */
    public function getPriority(): int
    {
        return $this->priority;
    }

    /**
     * @param int $priority
     */
    public function setPriority(int $priority): void
    {
        $this->priority = $priority;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_TAGS;
    }
}
