<?php

namespace QUI\CmsImport\Entities;

use QUI;

/**
 * Class ImportTranslation
 *
 * Represents a QUIQQER translation for group [project/{IMPORT_PROJECT}]
 */
class ImportTranslation extends AbstractImportEntity
{
    const DATATYPE_JS = 'js';
    const DATATYPE_PHP = 'php';
    const DATATYPE_PHP_JS = 'php,js';

    /**
     * @var string
     */
    protected string $var;

    /**
     * @var array
     */
    protected array $translations = [];

    /**
     * @var string
     */
    protected string $datatype;

    /**
     * @var bool
     */
    protected bool $isHtml = false;

    /**
     * ImportTranslation constructor.
     *
     * @param int|string $identifier - Unique identifier for this ImportTranslation
     * @param string $var - Translation variable
     * @param string $datatype - Translation datatype (one of self::DATATYPE_*)
     * @param bool $html - Does translation contain HTML?
     */
    public function __construct(
        int | string $identifier,
        string $var,
        string $datatype = self::DATATYPE_PHP_JS,
        bool $html = false
    ) {
        $this->var = $var;
        $this->datatype = $datatype;
        $this->isHtml = $html;
        parent::__construct($identifier);
    }

    /**
     * Set translation text for a language
     *
     * @param string $lang
     * @param string $translation
     * @return void
     */
    public function setTranslationForLanguage(string $lang, string $translation): void
    {
        $this->translations[$lang] = $translation;
    }

    /**
     * @return string
     */
    public function getVar(): string
    {
        return $this->var;
    }

    /**
     * @return array
     */
    public function getTranslations(): array
    {
        return $this->translations;
    }

    /**
     * @return string
     */
    public function getDatatype(): string
    {
        return $this->datatype;
    }

    /**
     * @return bool
     */
    public function isHtml(): bool
    {
        return $this->isHtml;
    }

    /**
     * Get the import section the ImportEntity belongs to
     *
     * @return string
     */
    public function getImportSection(): string
    {
        return QUI\CmsImport\Import::IMPORT_SECTION_TRANSLATIONS;
    }
}
