<?php

namespace QUI\CmsImport\MetaEntities;

use Generator;
use QUI;

class MetaEntity extends QUI\QDOM implements ChildrenInterface
{
    /**
     * @var int|string
     */
    protected string | int $id;

    /**
     * @var string|int
     */
    protected string | int $parentId;

    /**
     * @var MetaList
     */
    protected MetaList $ChildrenList;

    /**
     * HierarchyItem constructor.
     *
     * @param int|string $id - Unique identifier
     * @param int|string|null $parentId (optional) - Unique identifier of parent MetaHierarchyItem
     */
    public function __construct(
        int | string $id,
        null | int | string $parentId = null
    ) {
        $this->id = $id;
        $this->ChildrenList = new MetaList();
        $this->parentId = $parentId;
    }

    /**
     * @return MetaList
     */
    public function getChildrenList(): MetaList
    {
        return $this->ChildrenList;
    }

    /**
     * Add a child to the list
     *
     * @param MetaEntity $Item
     * @return void
     */
    public function addChild(MetaEntity $Item): void
    {
        $this->ChildrenList->addChild($Item);
    }

    /**
     * Get a child from the list
     *
     * @param int|string $id
     * @return bool|MetaEntity
     */
    protected function getChild(int | string $id): bool | MetaEntity
    {
        return $this->ChildrenList->getChild($id);
    }

    /**
     * Does this MetaItem have children?
     *
     * @return bool
     */
    public function hasChildren(): bool
    {
        return $this->ChildrenList->hasChildren();
    }

    /**
     * Walk the list of children
     *
     * @return Generator
     */
    public function walkChildren(): Generator
    {
        return $this->ChildrenList->walkChildren();
    }

    /**
     * @return int|string
     */
    public function getId(): int | string
    {
        return $this->id;
    }

    /**
     * @return int|string|null
     */
    public function getParentId(): int | string | null
    {
        return $this->parentId;
    }

    /**
     * @param string $attribute - Name of the attribute that is sorted by
     * @param string $type - Type of sort (see ChildrenInterface::SORT_TYPE_*)
     * @return void
     */
    public function sortChildren(string $attribute, string $type = self::SORT_TYPE_ASC): void
    {
        $this->ChildrenList->sortChildren($attribute, $type);
    }

    /**
     * Sort children by a custom sort function
     *
     * @param callable $sortFunc
     * @return void
     */
    public function sortChildrenCustom(callable $sortFunc): void
    {
        $this->ChildrenList->sortChildrenCustom($sortFunc);
    }
}
