<?php

namespace QUI\CmsImport\MetaEntities;

class ProjectEntity extends MetaEntity
{
    /**
     * @var array
     */
    protected array $languages = [];

    /**
     * @var ?string
     */
    protected ?string $defaultLanguage = null;

    /**
     * @var bool
     */
    protected bool $default = false;

    /**
     * @return bool
     */
    public function isDefault(): bool
    {
        return $this->default;
    }

    /**
     * Set project default status
     *
     * @param bool $default
     */
    public function setDefault(bool $default): void
    {
        $this->default = $default;
    }

    /**
     * @param string $lang
     * @param bool $default (optional) - Default project language? [default: false]
     */
    public function addLanguage(string $lang, bool $default = false): void
    {
        $this->languages[] = $lang;

        if ($default) {
            $this->defaultLanguage = $lang;
        }
    }

    /**
     * @return array
     */
    public function getLanguages(): array
    {
        return array_values(array_unique($this->languages));
    }

    /**
     * @return string
     */
    public function getDefaultLanguage(): string
    {
        return $this->defaultLanguage;
    }
}
